#!/bin/bash

set -o errexit
set -o xtrace

if [[ ! -v KOLLA_BOOTSTRAP && \
  "$(ls -A /var/lib/mysql)" == "" ]]; then
/usr/sbin/mysqld \
    --initialize-insecure \
    --user=mysql
fi

# Only update permissions if permissions need to be updated
if [[ $(stat -c %U:%G /var/lib/mysql) != "mysql:mysql" ]]; then
    sudo chown mysql: /var/lib/mysql
fi

# Bootstrap and exit if KOLLA_BOOTSTRAP variable is set. This catches all cases
# of the KOLLA_BOOTSTRAP variable being set, including empty.
if [[ "${!KOLLA_BOOTSTRAP[@]}" ]]; then
    : ${MYSQLCLUSTER_ROOT_PASSWORD?"ERROR - no db password given"}

    TIMEOUT=${DB_MAX_TIMEOUT:-60}
    while [[ ! -S /var/lib/mysql/mysql.sock ]]; do
        if [[ ${TIMEOUT} -gt 0 ]]; then
            let TIMEOUT-=1
            sleep 1
        else
            exit 1
        fi
    done

    if mysql --skip-password -u root < /dev/null &> /dev/null; then
        echo "Reset root password for new install..."
        mysql --skip-password -uroot \
          -e "SET PASSWORD = PASSWORD('$MYSQLCLUSTER_ROOT_PASSWORD');"

        echo "Remove test database, emtpy users, etc..."
        mysql -uroot -p$MYSQLCLUSTER_ROOT_PASSWORD << EOF
DELETE FROM mysql.user WHERE User='';
DROP DATABASE IF EXISTS test;
DELETE FROM mysql.db WHERE Db='test' OR Db='test\\_%';
FLUSH PRIVILEGES;
EOF

        echo "Add remote root..."
        mysql -uroot -p$MYSQLCLUSTER_ROOT_PASSWORD \
          -e "GRANT ALL PRIVILEGES ON *.* TO 'root'@'%' IDENTIFIED BY '$MYSQLCLUSTER_ROOT_PASSWORD' WITH GRANT OPTION;"

        echo "Setting up distributed privileges..."
        mysql -uroot -p$MYSQLCLUSTER_ROOT_PASSWORD < /usr/share/mysql/ndb_dist_priv.sql

        mysql -uroot -p$MYSQLCLUSTER_ROOT_PASSWORD -e "CALL mysql.mysql_cluster_move_privileges();"
    fi

    exit 0
fi

